@@ -1,7 +1,10 @@
 import requests
 import time
+import logging
 from yyweaknet.stf import STFServer
 
+logger = logging.getLogger()
+
 
 class WeakNetworkConfig(object):
     """
@@ -36,58 +39,56 @@ class WeakNetworkConfig(object):
         self._device_ip_list = []
         self.platform = None
 
-    def _get_device_info(self, platform='ios'):
+    def _get_device_info(self, serial):
         """
             获取当前设备信息
-            :param platform: ios/android
+            :param serial: 设备uuid
         """
-        self.platform = platform
-        for serial in self._serial_list:
-            device = self._stf.get_device_info(serial, platform)
-            if device:
-                self._device_list.append(device)
-            else:
-                raise Exception('No devices:{} found'.format(serial))
+        device = self._stf.get_device_info(serial, self.platform)
+        logger.info("get ios device info:{}".format(device))
+        if device:
+            return device
+        else:
+            raise None
 
-    def connect_wifi(self, serial_list, platform='ios'):
+    def connect_wifi(self, serial, platform='ios'):
         """
             连接弱网WIFI热点
         """
-        self._serial_list = serial_list
         self.platform = platform
         if self.platform == 'ios':
-            self._get_device_info(platform=platform)
-            for dev in self.device:
-                if self._connect_ios(dev):
-                    continue
-                else:
-                    return False
-            return True
+            device = self._get_device_info(serial)
+            if device is None:
+                return None
+            ip = self._connect_ios(device)
+            if ip:
+                return ip
+            else:
+                return None
         else:
-            for serial in serial_list:
-                if self._connect_android(serial):
-                    continue
-                else:
-                    return False
-            return True
+            ip = self._connect_android(serial)
+            if ip:
+                return ip
+            else:
+                return None
 
-    def disconnect_wifi(self):
+    def disconnect_wifi(self, serial):
         """
             断开弱网WIFI热点
         """
         if self.platform == 'ios':
-            return self._disconnect_ios()
+            return self._disconnect_ios(serial)
         else:
-            return self._disconnect_android()
+            return self._disconnect_android(serial)
 
     def _connect_android(self, serial):
         ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
+        logger.info("get toggleAndroidWifi response :{}".format(ret))
         ip = ret.get("ip", None)
         if str(ip).startswith("192.168.0"):
-            self._device_ip_list.append(ip)
-            return True
+            return ip
         else:
-            return False
+            return None
 
     def _connect_ios(self, device):
         # 发送自动点击弹窗配置
@@ -99,38 +100,43 @@ class WeakNetworkConfig(object):
         while True:
             if time.time() - t1 > timeout:
                 raise Exception('get_device_ip:{} timeout:{}'.format(device['wda_url'], timeout))
-            self._device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
-            if self._device_ip:
-                self._device_ip_list.append(self._device_ip)
+            device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
+            logger.info("get device_ip {}".format(device_ip))
+            if device_ip:
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
-                if self._device_ip.startswith('192.168.0'):
-                    self._set_auth()
-                    return True
+                if device_ip.startswith('192.168.0'):
+                    self._set_auth(device_ip)
+                    return device_ip
                 else:
-                    return False
+                    return None
 
-    def _disconnect_android(self):
-        for serial in self._serial_list:
-            ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
-            ip = ret.get("ip", None)
-            if not str(ip).startswith("192.168.0"):
-                continue
-            else:
-                return False
-        return True
+    def _disconnect_android(self, serial):
+        ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
+        logger.info("_disconnect_android response".format(ret))
+        ip = ret.get("ip", None)
+        if not str(ip).startswith("192.168.0"):
+            return True
+        else:
+            return False
 
-    def _disconnect_ios(self):
-        for dev in self._device_list:
-            self.bundle_id = self._stf.find_ios_bundle_id(dev['serial'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-            if self.bundle_id is None:
-                raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
-            self._stf.stop_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-            self._stf.launch_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
+    def _disconnect_ios(self, serial):
+        self.bundle_id = self._stf.find_ios_bundle_id(serial, WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        device = self._get_device_info(serial)
+        if self.bundle_id is None or device is None:
+            raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
+        self._stf.stop_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        self._stf.launch_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
+        time.sleep(10)
+        device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
+        logger.info("get device_ip {}".format(device_ip))
+        if device_ip.startswith('192.168.0') is False:
+            return True
 
-    def _set_auth(self):
+    def _set_auth(self, device_ip):
         url = "{host}{uri}".format(host=self._atc_host,
-                                   uri=WeakNetworkConfig.ATC_AUTH_URI.format(self._device_ip))
+                                   uri=WeakNetworkConfig.ATC_AUTH_URI.format(device_ip))
         r = requests.post(url)
+        logger.info("set_auth response {}".format(r.text))
         try:
             if r.status_code == 200:
                 return True
@@ -139,23 +145,23 @@ class WeakNetworkConfig(object):
         except Exception as e:
             return False
 
-    def set_net_config(self, config_json):
+    def set_net_config(self, ip, config_json):
         """
+        :param ip: ip地址
         :param config_json: 弱网配置参数
         :return: True if successful
         """
-        for device_ip in self._device_ip_list:
-            url = "{host}{uri}".format(host=self._atc_host,
-                                       uri=WeakNetworkConfig.ATC_SHAPE_URI.format(device_ip))
-            r = requests.post(url, json=config_json)
-            try:
-                if r.status_code == 200:
-                    continue
-                else:
-                    return False
-            except Exception as e:
+        url = "{host}{uri}".format(host=self._atc_host,
+                                   uri=WeakNetworkConfig.ATC_SHAPE_URI.format(ip))
+        r = requests.post(url, json=config_json)
+        logger.info("set_net_config response {}".format(r.text))
+        try:
+            if r.status_code == 200:
+                return True
+            else:
                 return False
-        return True
+        except Exception as e:
+            return False
 
 
 if __name__ == '__main__':
